@@ -84,7 +84,7 @@ ORBit_alloc_2(size_t block_size,
 #endif
 	block->free = freefunc;
 	block->func_data = func_data;
-	block->free_marker= FREE_MARKER_IS_ALLOCATED;
+	block->u.free_marker= FREE_MARKER_IS_ALLOCATED;
 
 	return MEMINFO_TO_PTR(block);
 }
@@ -116,7 +116,7 @@ ORBit_free(gpointer mem, CORBA_boolean ignore)
 	/* This block has not been allocated by CORBA_alloc. Instead
          * it is memory in the receive buffer, that has been used in
          * demarshalling. Let's just return. */
-	if (block->free_marker != FREE_MARKER_IS_ALLOCATED)
+	if (block->u.free_marker != FREE_MARKER_IS_ALLOCATED)
 		return;
 
 #ifdef ORBIT_DEBUG
