@@ -23,14 +23,22 @@
 #include "everything.h"
 #include "constants.h"
 
+#undef TIMING_RUN
+
+#ifndef TIMING_RUN
+#define d_print(a) g_print(a)
+#else
+#define d_print(a)
+#endif
+
 void testConst() {
-  g_print("Testing constants...\n");
+  d_print("Testing constants...\n");
   g_assert(test_CONST_CHAR=='t');
   g_assert(test_CONST_LONG==0x12345678);
   g_assert(test_CONST_LONGLONG==0x12345678);
   g_assert(strcmp(test_CONST_STRING,"ConstString")==0);
-  // I can never get constant floats to compare properly. 
-  //g_assert(test_CONST_FLOAT==1234.56);
+  /* I can never get constant floats to compare properly. */
+  /* g_assert(test_CONST_FLOAT==1234.56); */
   g_assert(test_CONST_DOUBLE==1234.5678);
   g_assert(test_FAVORITE_COLOUR==test_red);
 
@@ -42,7 +50,7 @@ void testAttribute(test_TestFactory factory,
   test_BasicServer objref;
   CORBA_char *val;
   CORBA_long lval;
-  g_print("Testing attributes...\n");
+  d_print("Testing attributes...\n");
   objref = test_TestFactory_getBasicServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
   val = test_BasicServer__get_foo(objref,ev);
@@ -64,7 +72,7 @@ void testString(test_TestFactory factory,
   test_BasicServer objref;
   const CORBA_char *in;
   CORBA_char *inout, *out, *retn; 
-  g_print("Testing strings...\n");
+  d_print("Testing strings...\n");
   objref = test_TestFactory_getBasicServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
   in = constants_STRING_IN;
@@ -89,7 +97,7 @@ void testLong(test_TestFactory factory,
 			  CORBA_Environment *ev) {
   test_BasicServer objref;
   CORBA_long inArg,inoutArg,outArg,retn;
-  g_print("Testing longs...\n");
+  d_print("Testing longs...\n");
   objref = test_TestFactory_getBasicServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
   inArg = constants_LONG_IN;
@@ -108,7 +116,7 @@ void testEnum(test_TestFactory factory,
 			  CORBA_Environment *ev) {
   test_BasicServer objref;
   test_AnEnum inArg,inoutArg,outArg,retn;
-  g_print("Testing enums...\n");
+  d_print("Testing enums...\n");
   objref = test_TestFactory_getBasicServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
   inArg = test_ENUM_IN;
@@ -127,7 +135,7 @@ void testException(test_TestFactory factory,
 				   CORBA_Environment *ev) {
   test_BasicServer objref;
   test_TestException *ex;
-  g_print("Testing exceptions...\n");
+  d_print("Testing exceptions...\n");
   objref = test_TestFactory_getBasicServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -150,7 +158,7 @@ void testFixedLengthStruct(test_TestFactory factory,
 						   CORBA_Environment *ev) {
   test_StructServer objref;
   test_FixedLengthStruct inArg,inoutArg,outArg,retn;
-  g_print("Testing fixed length structs...\n");
+  d_print("Testing fixed length structs...\n");
   objref = test_TestFactory_getStructServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -172,7 +180,7 @@ void testVariableLengthStruct(test_TestFactory factory,
 						   CORBA_Environment *ev) {
   test_StructServer objref;
   test_VariableLengthStruct inArg,inoutArg, *outArg, *retn;
-  g_print("Testing variable length structs...\n");
+  d_print("Testing variable length structs...\n");
   objref = test_TestFactory_getStructServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -199,7 +207,7 @@ void testCompoundStruct(test_TestFactory factory,
 						   CORBA_Environment *ev) {
   test_StructServer objref;
   test_CompoundStruct inArg,inoutArg, *outArg, *retn;
-  g_print("Testing compound structs...\n");
+  d_print("Testing compound structs...\n");
   objref = test_TestFactory_getStructServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -227,7 +235,7 @@ void testUnboundedSequence(test_TestFactory factory,
   test_SequenceServer objref;
   test_StrSeq inArg, inoutArg, *outArg, *retn;
   guint i;
-  g_print("Testing unbounded sequences...\n");
+  d_print("Testing unbounded sequences...\n");
   objref = test_TestFactory_getSequenceServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
   
@@ -277,7 +285,7 @@ void testBoundedSequence(test_TestFactory factory,
   test_SequenceServer objref;
   test_BoundedStructSeq inArg, inoutArg, *outArg, *retn;
   guint i;
-  g_print("Testing bounded sequences...\n");
+  d_print("Testing bounded sequences...\n");
   objref = test_TestFactory_getSequenceServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -330,7 +338,7 @@ void testFixedLengthUnion(test_TestFactory factory,
 						  CORBA_Environment *ev) {
   test_UnionServer objref;
   test_FixedLengthUnion inArg, inoutArg, outArg, retn;
-  g_print("Testing fixed length unions...\n");
+  d_print("Testing fixed length unions...\n");
   objref = test_TestFactory_getUnionServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -361,7 +369,7 @@ void testVariableLengthUnion(test_TestFactory factory,
 						  CORBA_Environment *ev) {
   test_UnionServer objref;
   test_VariableLengthUnion inArg, inoutArg, *outArg, *retn;
-  g_print("Testing variable length unions...\n");
+  d_print("Testing variable length unions...\n");
   objref = test_TestFactory_getUnionServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -397,7 +405,7 @@ void testFixedLengthArray(test_TestFactory factory,
   test_LongArray inArg, inoutArg, outArg;
   test_LongArray_slice *retn;
   int i;
-  g_print("Testing arrays with fixed length members...\n");
+  d_print("Testing arrays with fixed length members...\n");
   objref = test_TestFactory_getArrayServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -431,7 +439,7 @@ void testVariableLengthArray(test_TestFactory factory,
   test_StrArrayMultiDimensional_slice *multidim;
   int i,n0,n1,n2;
   
-  g_print("Testing arrays with variable length members...\n");
+  d_print("Testing arrays with variable length members...\n");
   objref = test_TestFactory_getArrayServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -474,7 +482,7 @@ void testAnyLong(test_TestFactory factory,
   CORBA_any inArg, inoutArg, *outArg, *retn;
   CORBA_long tmp, tmp1;
 
-  g_print("Testing any with longs...\n");
+  d_print("Testing any with longs...\n");
   objref = test_TestFactory_getAnyServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -524,7 +532,7 @@ void testAnyString(test_TestFactory factory,
   test_AnyServer objref;
   CORBA_any inArg, inoutArg, *outArg, *retn;
 
-  g_print("Testing any with strings...\n");
+  d_print("Testing any with strings...\n");
   objref = test_TestFactory_getAnyServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -574,7 +582,7 @@ void testAnyStruct(test_TestFactory factory,
   test_VariableLengthStruct inArgStruct; 
   test_VariableLengthStruct * inoutArgStruct;
 
-  g_print("Testing any with structs...\n");
+  d_print("Testing any with structs...\n");
 
   objref = test_TestFactory_getAnyServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
@@ -633,7 +641,7 @@ void testSequenceOfAny(test_TestFactory factory,
   test_AnySeq anyseq;
   int i;
 
-  g_print("Testing Sequence of Any...\n");
+  d_print("Testing Sequence of Any...\n");
 
   anyseq._buffer= CORBA_sequence_CORBA_any_allocbuf(2);
   anyseq._length= 2;
@@ -670,7 +678,7 @@ void testTypeCode(test_TestFactory factory,
   test_AnyServer objref;
   CORBA_TypeCode inArg, inoutArg, outArg, retn;
 
-  g_print("Testing TypeCodes...\n");
+  d_print("Testing TypeCodes...\n");
   objref = test_TestFactory_getAnyServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
@@ -715,7 +723,11 @@ int main(int argc, char *argv[]) {
 	g_assert(ev._major == CORBA_NO_EXCEPTION);
   }
 
-  for(i=0;i<20;i++){
+#ifdef TIMING_RUN
+  for(i=0;i<1000;i++){
+#else
+  for(i=0;i<1;i++){
+#endif
   testConst();
   testAttribute(factory,&ev);  
   testString(factory,&ev);
@@ -742,5 +754,9 @@ int main(int argc, char *argv[]) {
   CORBA_Object_release((CORBA_Object)orb, &ev);
   g_assert(ev._major == CORBA_NO_EXCEPTION);
 
+#ifdef TIMING_RUN
+  g_warning ("Did '%d' iterations", i);
+#endif
+
   return 0;
 }
